==> ingdao-0.0.2.tar.gz: example/datasync/lib/service/tanktimesheet/tanktimesheet_service.dart <==
import 'package:ingdao/dataflow/service/dfservice.dart';
import '../../datalayer/data_factory.dart';

import '../../datalayer/field/tanktimesheet/tanktimesheet_field.dart';

import 'package:ingdao/ingdao.dart';
import 'package:ingdao/dataflow/field/dfbasefield.dart';
import 'package:ingdao/dataflow/control/dfquery.dart';
import 'package:ingdao/dataflow/control/dfquerypaging.dart';
import 'package:ingdao/dataflow/control/dfqueryorderby.dart';
import 'package:ingdao/dataflow/control/dfresponse.dart';
import 'package:ingdao/dataflow/control/dfquerycriteriagroup.dart';
import 'package:ingdao/dataflow/control/dfquerycriteria.dart';
import 'package:ingdao/dataflow/control/dfqueryentityjoin.dart';
import 'package:ingdao/dataflow/repository/dfbaserepository.dart';
import 'package:ingdao/dataflow/entity/dfbaseentity.dart';
import '../../datalayer/fetchentityresult.dart';
import '../../datalayer/entity/tanktimesheet/tanktimesheetbean.dart';

class TankTimesheetService extends DfService {
  @override
  startInit() {
  }

  Future<List<DfResponse>> saveTimesheet(List<TankTimesheetBean> entries) async {
    DfFactory dbFactory = await DataFactory.instance.getManipulator(RepositoryType.sqlitedb);
    DfBaseRepository repository = dbFactory.currentRepository;
    DfBaseEntity tankTimeSheetEntity = repository.model.entities[0];

    List<DfBaseEntity> timesheetEntries = List<DfBaseEntity>();
    entries.forEach((entry) {
      TankTimesheetField entF = TankTimesheetField.createFieldBasedOnRepo(repository);
      print("Save data.... ${entry.markOn}");
      entry.setTo(field: entF);
      timesheetEntries.add(entF as DfBaseEntity);
    });

    List<DfQuery> timesheetEntriesSaveQueries = List<DfQuery>();
    timesheetEntries.forEach((entry) {
      DfQuery query = DfQuery(purpose: DfQueryPurpose.ADD, queryFields: entry.toMap(), entityJoin: DfQueryEntityJoin(entities: [tankTimeSheetEntity])  );
      timesheetEntriesSaveQueries.add(query);
    });
    return await dbFactory.save(timesheetEntriesSaveQueries);
  }

  Future<FetchEntityResult<TankTimesheetBean>> fetchTimesheet(String tankId, int pageNumber, int limit) async {
    DfFactory webFactory = await DataFactory.instance.getManipulator(RepositoryType.web);
    DfFactory dbFactory = await DataFactory.instance.getManipulator(RepositoryType.sqlitedb);

    FetchEntityResult<TankTimesheetField> webResult;

    //Check table got record, if no, then only fetch from web
    FetchEntityResult<TankTimesheetField> checkDbResult = await _fetch(dbFactory, tankId, 1, 1);
    if (checkDbResult.entities == null || checkDbResult.entities.length == 0) {
      //Fetch from web
      webResult = await _fetch(webFactory, tankId, pageNumber, limit);
      if (webResult.error == null) {
        //Save to db
        DfBaseRepository repository = dbFactory.currentRepository;
        DfBaseEntity tankTimeSheetEntity = repository.model.entities[0];

        List<DfBaseEntity> timesheetEntries = List<DfBaseEntity>();
        webResult.entities.forEach((webEnt) {
          TankTimesheetField entF = TankTimesheetField.createFieldBasedOnRepo(repository);
          entF.fId.value = webEnt.fId.value;
          entF.fTankId.value = webEnt.fTankId.value;
          entF.fName.value = webEnt.fName.value;
          entF.fMarkOn.value = webEnt.fMarkOn.value;
          entF.fActive.value = webEnt.fActive.value;
          timesheetEntries.add(entF as DfBaseEntity);
        });

        List<DfQuery> timesheetEntriesSaveQueries = List<DfQuery>();
        timesheetEntries.forEach((entry) {
          DfQuery query = DfQuery(purpose: DfQueryPurpose.ADD, queryFields: entry.toMap(), entityJoin: DfQueryEntityJoin(entities: [tankTimeSheetEntity])  );
          timesheetEntriesSaveQueries.add(query);
        });
        await dbFactory.save(timesheetEntriesSaveQueries);
      }
    }

    //Fetch latest from db
    FetchEntityResult<TankTimesheetField> dbResult = await _fetch(dbFactory, tankId, pageNumber, limit);
    if (webResult != null && webResult.error != null) {
      dbResult.error = webResult.error;
    }

    FetchEntityResult<TankTimesheetBean> retResult = FetchEntityResult<TankTimesheetBean>();
    retResult.error = dbResult.error;
    List<TankTimesheetBean> beanlist = [];
    if (dbResult.entities != null) {
      dbResult.entities.forEach((field) {
        beanlist.add(TankTimesheetBean.from(field: field));
      });
    }
    retResult.entities = beanlist;
    return retResult;
  }

  Future<FetchEntityResult<TankTimesheetField>> _fetch(DfFactory factory, String tankId, int pageNumber, int limit) async {
    DfBaseRepository repository = factory.currentRepository;
    DfBaseEntity tankTimeSheetEntity = repository.model.entities[0];
    TankTimesheetField tankTimesheetField = TankTimesheetField.createFieldBasedOnRepo(repository);

    List<DfBaseField> selFields = tankTimeSheetEntity.fields();

    List<DfQueryCriteria> criterias = [];
    if (tankId != null && tankId.length > 0) {
      criterias.add(DfQueryCriteria(field: tankTimesheetField.fTankId, oper: OperType.eq, values: [tankId] ));
    }

    DfQueryOrderBy orderBy =DfQueryOrderBy(field: tankTimesheetField.fName, orderByType: OrderByType.asc);
    Paging paging = Paging(pageNumber: pageNumber, perPageCount: limit);

    DfQuery query = DfQuery(purpose: DfQueryPurpose.FETCH, 
                            queryFields: selFields, 
                            entityJoin: DfQueryEntityJoin(entities: [tankTimeSheetEntity], 
                            joins: []), //JoinType.innerJoin 
                            criteriaGroup: DfQueryCriteriaGroup(criterias: criterias), 
                            orderBy: [orderBy], 
                            paging: paging);
    List<TankTimesheetField> list = List<TankTimesheetField>();
    DfResponse resp = await factory.fetch(query);
    if (resp.error == null) {
      List<Map<String,dynamic>> resultSet = resp.result;
      resultSet.forEach((result) {
        DfBaseEntity ent = tankTimeSheetEntity.newInstance();
        ent.fromMap(result);
        TankTimesheetField entF = ent as TankTimesheetField;
        list.add(entF);
      });
    }
    return FetchEntityResult<TankTimesheetField>(entities: list, error: resp.error);
  }

}

==> ingdao-0.0.5.tar.gz: example/datasync/lib/service/tanktimesheet/tanktimesheet_service.dart <==
import 'package:ingdao/dataflow/service/dfservice.dart';
import '../../datalayer/data_factory.dart';

import '../../datalayer/field/tanktimesheet/tanktimesheet_field.dart';
import '../../datalayer/entity/tanktimesheet/tanktimesheet.dart';
import '../../datalayer/entity/tanktimesheet/tanktimesheetweb.dart';

import 'package:ingdao/ingdao.dart';
import 'package:ingdao/dataflow/field/dfbasefield.dart';
import 'package:ingdao/dataflow/control/dfquery.dart';
import 'package:ingdao/dataflow/control/dfquerypaging.dart';
import 'package:ingdao/dataflow/control/dfqueryorderby.dart';
import 'package:ingdao/dataflow/control/dfresponse.dart';
import 'package:ingdao/dataflow/control/dfquerycriteriagroup.dart';
import 'package:ingdao/dataflow/control/dfquerycriteria.dart';
import 'package:ingdao/dataflow/control/dfqueryentityjoin.dart';
import 'package:ingdao/dataflow/repository/dfbaserepository.dart';
import 'package:ingdao/dataflow/entity/dfbaseentity.dart';
import '../../datalayer/fetchentityresult.dart';

class TankTimesheetService extends DfService {
  @override
  startInit() {
    print("Service startInit");
  }

  Future<List<DfResponse>> saveTimesheet(List<TankTimesheet> entries) async {
    DfFactory dbFactory = await DataFactory.instance.getManipulator(RepositoryType.sqlitedb);
    DfBaseRepository repository = dbFactory.currentRepository;
    DfBaseEntity tankTimeSheetEntity = repository.model.entities[0];

    List<DfQuery> timesheetEntriesSaveQueries = List<DfQuery>();
    entries.forEach((entry) {
      DfQuery query = DfQuery(purpose: DfQueryPurpose.ADD, queryFields: entry.toMap(), entityJoin: DfQueryEntityJoin(entities: [tankTimeSheetEntity])  );
      timesheetEntriesSaveQueries.add(query);
    });
    return await dbFactory.save(timesheetEntriesSaveQueries);
  }

  Future<FetchEntityResult<TankTimesheet>> fetchTimesheet(String tankId, int pageNumber, int limit) async {
    DfFactory webFactory = await DataFactory.instance.getManipulator(RepositoryType.web);
    DfFactory dbFactory = await DataFactory.instance.getManipulator(RepositoryType.sqlitedb);

    FetchEntityResult<DfBaseEntity> webResult;

    //Check table got record, if no, then only fetch from web
    FetchEntityResult<DfBaseEntity> checkDbResult = await _fetch(dbFactory, tankId, 1, 1);
    if (checkDbResult.entities == null || checkDbResult.entities.length == 0) {
      //Fetch from web
      webResult = await _fetch(webFactory, tankId, pageNumber, limit);
      if (webResult.error == null) {
        //Save to db
        DfBaseRepository repository = dbFactory.currentRepository;
        DfBaseEntity tankTimeSheetEntity = repository.model.entities[0];

        List<DfQuery> timesheetEntriesSaveQueries = List<DfQuery>();
        webResult.entities.forEach((entry) {
          TankTimesheetWeb tankTimesheetWeb = entry;
          TankTimesheet saveObj = TankTimesheet();
          saveObj.id = tankTimesheetWeb.id;
          saveObj.name = tankTimesheetWeb.name;
          saveObj.active = tankTimesheetWeb.active;
          saveObj.tankId = tankTimesheetWeb.tankId;
          saveObj.markOn = tankTimesheetWeb.markOn;
          print("saveObj.name ${saveObj.id} ${saveObj.name}");
          DfQuery query = DfQuery(purpose: DfQueryPurpose.ADD, queryFields: saveObj.toMap(), entityJoin: DfQueryEntityJoin(entities: [tankTimeSheetEntity])  );
          timesheetEntriesSaveQueries.add(query);
        });
        await dbFactory.save(timesheetEntriesSaveQueries);
      }
    }

    //Fetch latest from db
    FetchEntityResult<DfBaseEntity> dbResult = await _fetch(dbFactory, tankId, pageNumber, limit);
    if (webResult != null && webResult.error != null) {
      dbResult.error = webResult.error;
    }

    FetchEntityResult<TankTimesheet> finalResult = FetchEntityResult<TankTimesheet>();
    finalResult.error = dbResult.error;
    if (dbResult.entities != null) {
      finalResult.entities = List<TankTimesheet>();
      dbResult.entities.forEach((ent) {
        finalResult.entities.add(ent as TankTimesheet); 
      });
    }

    return finalResult;
  }

  Future<FetchEntityResult<DfBaseEntity>> _fetch(DfFactory factory, String tankId, int pageNumber, int limit) async {
    DfBaseRepository repository = factory.currentRepository;
    DfBaseEntity tankTimeSheetEntity = repository.model.entities[0];
    TankTimesheetField tankTimesheetField = TankTimesheetField.createFieldBasedOnRepo(repository);

    List<DfBaseField> selFields = tankTimeSheetEntity.fields();

    List<DfQueryCriteria> criterias = [];
    if (tankId != null && tankId.length > 0) {
      criterias.add(DfQueryCriteria(field: tankTimesheetField.fTankId, oper: OperType.eq, values: [tankId] ));
    }

    DfQueryOrderBy orderBy =DfQueryOrderBy(field: tankTimesheetField.fName, orderByType: OrderByType.asc);
    Paging paging = Paging(pageNumber: pageNumber, perPageCount: limit);

    DfQuery query = DfQuery(purpose: DfQueryPurpose.FETCH, 
                            queryFields: selFields, 
                            entityJoin: DfQueryEntityJoin(entities: [tankTimeSheetEntity], 
                            joins: []), //JoinType.innerJoin 
                            criteriaGroup: DfQueryCriteriaGroup(criterias: criterias), 
                            orderBy: [orderBy], 
                            paging: paging);

    DfResponse resp = await factory.fetch(query);
    List<DfBaseEntity> finalList;
    if (resp.error == null) {
      if (tankTimeSheetEntity is TankTimesheet) {
        resp.result.forEach((rawDbRow) {
          print("rawDbRow: $rawDbRow");
        });
        finalList = resp.renderResultToList<TankTimesheet>();

        if (finalList != null) {
          finalList.forEach((ent) {
            TankTimesheet dbObj = ent;
            print("dbobj name: ${dbObj.name}");
          });
        }
      }
      else {
        resp.result.forEach((rawWebRow) {
          print("rawWebRow: $rawWebRow");
        });
        finalList = resp.renderResultToList<TankTimesheetWeb>();
        if (finalList != null) {
          finalList.forEach((ent) {
            TankTimesheetWeb webObj = ent;
            print("webobj name: ${webObj.name} ${webObj.markOn} ${webObj.active}");
          });
        }
      }
    }

    return FetchEntityResult<DfBaseEntity>(entities: finalList, error: resp.error);
  }
}
